Bio2BEL
=======
.. automodule:: bio2bel

Table of Contents
=================
.. toctree::
   :maxdepth: 2

   introduction
   repositories
   tutorial
   cli

.. toctree::
   :maxdepth: 2
   :caption: Reference
   :name: reference

   downloading
   utils
   testing

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
